Crate elvish

Crate elvish 

elvish

Overengineered Advent of Code framework for Rust - not quite Santa’s elves.

elvish is a framework for writing your Advent of Code solutions with the least amount of boilerplate as possible.

Features

  • Declare solutions with simple macro
  • Fetching and caching of user input
  • Run solutions as binary
  • Automatically copy solutions to clipboard
  • Simple and consice syntax to write out 90% of required tests
  • See the puzzle description as docs on the annotated function
  • Conditional compilation to compile a single day

Re-exports

pub use elvish_macros as macros;
pub use color_eyre::eyre;

Modules

data
Getting data from advent of code, and data required to get data from advent of code (year and session token).
declare
Convinience for declaring 25-sets with feature flags at once.
solution
Traits for declaring solutions of advent of code puzzles, and functions for running them.

Macros

available_days
Declares an array of available days, based on feature flags.
example
Defines examples given in advent of code puzzles. The strings in the example are unindented using indoc.
indoc
Unindent and produce &'static str or &'static [u8].

Functions

copy_to_clipboard
Copy the output of the solution to the clipboard.
run
Runs elvish.

Type Aliases

Part
Either part 1 (0) or part 2 (1)

Attribute Macros

solution
A solution of an advent of code problem.